==> libwpd-0.7.2.tar.bz2: libwpd-0.7.2/src/lib/WP5UnsupportedVariableLengthGroup.h <==
/* libwpd
 * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
 * Copyright (C) 2003 Marc Maurer (j.m.maurer@student.utwente.nl)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP5UNSUPPORTEDVARIABLELENGTHGROUP_H
#define WP5UNSUPPORTEDVARIABLELENGTHGROUP_H

#include "WP5VariableLengthGroup.h"

// a pedantic and irritating class that we should only need until we completely cover wordperfect's
// set of variable length groups (there are a finite number)

class WP5UnsupportedVariableLengthGroup : public WP5VariableLengthGroup
{
public:
	WP5UnsupportedVariableLengthGroup(GsfInput *input);
	virtual void parse(WP5HLListener *listener) {}
};

#endif /* WP5UNSUPPORTEDVARIABLELENGTHGROUP_H */

==> libwpd-0.8.6.tar.bz2: libwpd-0.8.6/src/lib/WP5UnsupportedVariableLengthGroup.h <==
/* libwpd
 * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
 * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP5UNSUPPORTEDVARIABLELENGTHGROUP_H
#define WP5UNSUPPORTEDVARIABLELENGTHGROUP_H

#include "WP5VariableLengthGroup.h"

// a pedantic and irritating class that we should only need until we completely cover wordperfect's
// set of variable length groups (there are a finite number)

class WP5UnsupportedVariableLengthGroup : public WP5VariableLengthGroup
{
public:
	WP5UnsupportedVariableLengthGroup(WPXInputStream *input);
	void parse(WP5Listener *listener) {}
};

#endif /* WP5UNSUPPORTEDVARIABLELENGTHGROUP_H */
